@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2016-10-07'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2017-01-04'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -307,8 +307,12 @@ sub _parse_raw_value {
 sub _decode_json {
     my ($self, $val) = @_;
     state $json = do {
-        require JSON;
-        JSON->new->allow_nonref;
+        if (eval { require Cpanel::JSON::XS; 1 }) {
+            Cpanel::JSON::XS->new->allow_nonref;
+        } else {
+            require JSON::PP;
+            JSON::PP->new->allow_nonref;
+        }
     };
     my $res;
     eval { $res = $json->decode($val) };
@@ -432,7 +436,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.28 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-10-07.
+This document describes version 0.29 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2017-01-04.
 
 =head1 EXPRESSION
 
@@ -647,7 +651,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
